@@ -620,32 +620,36 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
       "mv -vf fullauto_clickable_image.png $sd",'__display__');
    ($stdout,$stderr)=$local->cmd($sudo.
       "rm -rvf fullauto_clickable_image.png",'__display__');
-   $ad="        'fullauto' =>%NL%".
-      "        array('url' => 'http://www.fullauto.com',%NL%".
-      "              'title' => 'FullAuto - Automates EVERYTHING',%NL%".
-      "              'image' => %NL%".
-      "\$_path.'/theme/base/fullauto_clickable_image.png'),%NL%";
+   $ad="        %SQ%fullauto%SQ% =>%NL%".
+      "        array(%SQ%url%SQ% => %SQ%http://www.fullauto.com%SQ%,%NL%".
+      "              %SQ%title%SQ% => %SQ%FullAuto - Automates EVERYTHING%SQ%,%NL%".
+      "              %SQ%image%SQ% => %NL%".
+      "\$_path.%SQ%/theme/base/fullauto_clickable_image.png%SQ%),%NL%";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
       "\'/cc_by_3.0_80x15/a$ad\' /var/www/gnusocial/lib/default.php");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
+       '/var/www/gnusocial/lib/default.php');
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
        "/var/www/gnusocial/lib/default.php");
    $handle->cmd_raw(
-       "${sudo}sed -i 's#\\(^'fullauto' =[>]$\\\)#        \\1#' ".
+       "${sudo}sed -i 's#\\(^[']fullauto['] =[>]$\\\)#        \\1#' ".
        '/var/www/gnusocial/lib/default.php');
    $ad='    function showFullAuto()%NL%'.
       '    {%NL%'.
-      "        \$this->elementStart('div', array('id' => 'fullauto'));%NL%".
-      "        \$image    = common_config('fullauto', 'image');%NL%".
-      "        \$this->element('img', array('id' => 'fullauto',%NL%".
-      "                                    'src' => Theme::path('fullauto_clickable_image.png'),%NL%".
-      "                                    'alt' => common_config('fullauto', 'title'),%NL%".
-      "                                    'width' => '83',%NL%".
-      "                                    'height' => '40'));%NL%".
-      "        \$this->elementEnd('div');%NL%".
+      "        \$this->elementStart(%SQ%div%SQ%, array(%SQ%id%SQ% => %SQ%fullauto%SQ%));%NL%".
+      "        \$image    = common_config(%SQ%fullauto%SQ%, %SQ%image%SQ%);%NL%".
+      "        \$this->element(%SQ%img%SQ%, array(%SQ%id%SQ% => %SQ%fullauto%SQ%,%NL%".
+      "                                    %SQ%src%SQ% => Theme::path(%SQ%fullauto_clickable_image.png%SQ%),%NL%".
+      "                                    %SQ%alt%SQ% => common_config(%SQ%fullauto%SQ%, %SQ%title%SQ%),%NL%".
+      "                                    %SQ%width%SQ% => %SQ%83%SQ%,%NL%".
+      "                                    %SQ%height%SQ% => %SQ%40%SQ%));%NL%".
+      "        \$this->elementEnd(%SQ%div%SQ%);%NL%".
       "    }%NL%";
    ($stdout,$stderr)=$handle->cmd("${sudo}sed -i ".
       "\'/function showFooter/i$ad\' /var/www/gnusocial/lib/action.php");
+   ($stdout,$stderr)=$handle->cmd("${sudo}sed -i \"s/%SQ%/\'/g\" ".
+       '/var/www/gnusocial/lib/action.php');
    ($stdout,$stderr)=$handle->cmd(
        "${sudo}sed -i \'s/%NL%/\'\"`echo \\\\\\n`/g\" ".
        "/var/www/gnusocial/lib/action.php");
